
package art;

import java.util.Hashtable;

/**
 * This class represents classes that implement
 * classical style animations, which should
 * be a Node of some sort, such as a group 
 * or Shape.
 * @author Kenneth Dallmann
 */
abstract public interface FrameByFrameAnimation {
	
	public abstract String[] getAnimationNames();
	public abstract void play(String motion);
	/**
	 * plays a sequence, if the boolean value is true then it will 
	 * play it with a saved transform, which you must first save
	 * using setSequenceTransform(...);
	 */
	public abstract void play(String motion, boolean useSavedTransform);
	/**
	 * Clears the sequence queue and then plays one given by parameters. 
	 */
	public abstract void playOne(String motion, boolean useSavedTransform) ;
	public abstract void setFrameRate(int rate);
	/**
	 * This method is intended to save the data given
	 * in a Hashtable, then it will be automatically
	 * used if play(String anim, boolean useSavedTransform) is 
	 * called.
	 * @param anim: The frame sequence's name to be associated with this transform.
	 * @param transform: The seven or zero length array, throws NullPointerException otherwise.
	 */
	public abstract void setSequenceTransform(String anim, double[] transform);
	/**
	 * @return the lengths, in frames, of their associated String sequence.  
	 */
	public abstract Hashtable<String, Integer> getLengths();
	/**
	 * Adds the sequence to a linked queue, which will tell 
	 * the object to play the sequence. The transforms array represents
	 * the data needed to make a transformations, if no action is 
	 * wanted set the values for those actions to zero, if no translation
	 * is wanted then call the overloaded play() method, which uses empty
	 * translations, it is also possible to call this method and pass in
	 * an array of size 0, which does no translation, and is the same 
	 * as the other play method.   The transforms array must be 
	 * 7 in length, 0-6.
	 * 
	 * Scaling is done scale value +1, so 0 = 1, hence you can make characters grow from the original size. 
	 * 
	 * *Any number in the array that is set to zero will be ignored.
	 * *If any of the if any of the first three are set zero, all 3 will be ignored.
	 * *If any of the 3-4 5-6, indexes, are set to zero then the set, of two, will be ignored.
	 * *Values given may be positive or negative, other than on the scale values. 
	 * 
	 * @param motion: The frame sequence to play.
	 * @param transforms: A double array which tells this object to make
	 * a translation, which will be divided across every sequence frame
	 * evenly. (seconds/value[x] is used on data passed in). [0] = rotate value,
	 * [1]=anchorX, [2]=anchorY, [3]=translateX(move). [4]=translateY(move), 
	 * [5]=scaleX, [6]=scaleY.
	 */
	void play(String motion, double[] transforms);
	/**
	 * Clears the frame sequence queue and stops all animations. 
	 */
	public abstract void stop();
}
